@@ -123,7 +123,7 @@
 				}
 
 				if ($match && (strlen($line) >= strlen($module))) {
-					$module = str_replace("*/", "", $line);
+					$module = page_to_module($line);
 				}
 			}
 
@@ -145,9 +145,9 @@
 		 * OUTPUT: string module identifier
 		 * ERROR:  -
 		 */
-		private function page_in_database($url, $type) {
+		private function page_in_database($url, $private) {
 			$query = "select id,visible from pages where url=%s and private=%d limit 1";
-			if (($result = $this->db->execute($query, "/".$url, $type)) == false) {
+			if (($result = $this->db->execute($query, "/".$url, $private)) == false) {
 				return null;
 			}
 
@@ -201,7 +201,7 @@
 			 */
 			if (($this->module = $this->page_on_disk($page, "public_pages")) !== null) {
 				return;
-			} else if (($this->module = $this->page_in_database($page, PUBLIC_PAGE)) !== null) {
+			} else if (($this->module = $this->page_in_database($page, NO)) !== null) {
 				return;
 			}
 
@@ -217,7 +217,7 @@
 			/* Private page
 			 */
 			if (($this->module = $this->page_on_disk($page, "private_pages")) === null) {
-				$this->module = $this->page_in_database($page, PRIVATE_PAGE);
+				$this->module = $this->page_in_database($page, YES);
 			}
 
 			if ($this->module == null) {
