@@ -9,7 +9,7 @@
 	/* For internal usage. Only change if you know what you're doing!
 	 */
 	define("BANSHEE_VERSION", "1.3");
-	define("MONITOR_VERSION", "0.1");
+	define("MONITOR_VERSION", "0.2");
 	define("ADMIN_ROLE_ID", 1);
 	define("YES", 1);
 	define("NO", 0);
@@ -18,8 +18,6 @@
 	define("USER_STATUS_ACTIVE", 2);
 	define("SESSION_NAME", "WebsiteSessionID");
 	define("PAGE_MODULE", "includes/page");
-	define("PUBLIC_PAGE", 0);
-	define("PRIVATE_PAGE", 1);
 	define("DAY", 86400);
 
 	/* Hiawatha Monitor settings
@@ -161,14 +159,14 @@
 			return $cache[$file];
 		}
 
-		$file = "../settings/".$file.".conf";
-		if (file_exists($file) == false) {
+		$config_file = "../settings/".$file.".conf";
+		if (file_exists($config_file) == false) {
 			return array();
 		}
 
 		$config = array();
-		foreach (file($file) as $line) {
-			if (($line = preg_replace("/#.*/", "", chop($line))) !== "") {
+		foreach (file($config_file) as $line) {
+			if (($line = preg_replace("/#.*/", "", trim($line))) !== "") {
 				array_push($config, $line);
 			}
 		}
