@@ -54,14 +54,6 @@
 		include($file);
 	}
 
-	/* Object-oriented page
-	 */
-	$class = str_replace("/", "_", $_page->module)."_ajax_controller";
-	if (class_exists($class)) {
-		$controller = new $class($db, $_page, $_user, $_output);
-		$controller->execute();
-	}
-
 	$_output->close_tag();
 
 	/* Output content
