@@ -39,7 +39,6 @@
 	$_user   = new user($db);
 	$_page   = new page($db, $_user);
 	$_output = new output($db, $_page);
-	#$_language = new language($db, $_page, $_output);
 
 	/* Include the model
 	 */
@@ -97,14 +96,6 @@
 		include($file);
 	}
 
-	/* Object-oriented page
-	 */
-	$class = str_replace("/", "_", $_page->module)."_controller";
-	if (class_exists($class)) {
-		$controller = new $class($db, $_user, $_page, $_output);
-		$controller->execute();
-	}
-
 	$_output->close_tag();
 
 	$_output->close_tag();
